pub struct CharWidthChangedEvent {
pub item: ObjectRefOwned,
}Expand description
The width of a terminal emulator has changed sufficiently such that the number of characters able to fit on one visual line has changed.
Fields
item: ObjectRefOwnedThe crate::ObjectRef which the event applies to.